;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.11.0" "Operations on the current project" '((emacs "26.1") (xref "1.7.0")) :commit "56871dbd4c1a1af3f0d1624f4858e9be67a89f7e" :url "https://elpa.gnu.org/packages/project.html")
